#define __TIFF2IOC_C
//------------------------------------------------------------------------------
//
//  Tiff2ioc.C
//
//  Convert a tiff file to AFP IOCA and include on a page using toolbox
//
//        >>>>>>>  IMPORTANT NOTICE   <<<<<<<<<<<
//
//   THIS PROGRAM IS NOT SUPPORTED IN ANY WAY BY IBM.  IT
//   HAS NOT BEEN SUBJECTED TO ANY FORMAL IBM TESTING AND
//   IS DISTRIBUTED ON AN "AS-IS" BASIS WITHOUT ANY
//   WARRANTY EITHER EXPRESSED OR IMPLIED.  THE USE OF
//   THIS CODE OR ANY INFORMATION OR TECHNIQUES IMPLICIT
//   WITHIN IT IS THE SOLE RESPONSIBILITY OF THE CUSTOMER.
//   SUCH USE DEPENDS UPON THE CUSTOMER'S ABILITY TO
//   EVALUATE THE INFORMATION IN THE CONTEXT OF THEIR OWN
//   PARTICULAR OPERATING ENVIRONMENT.  THIS CODE HAS
//   OPERATED SUCCESSFULLY IN THE COMPUTING ENVIRONMENT AT
//   THE BOULDER PROGRAMMING CENTER.  THERE IS NO
//   GUARANTEE THAT IT WILL OPERATE CORRECTLY ELSEWHERE.
//
//
//------------------------------------------------------------------------------

#include <stdlib.h>
#include <errno.h>
#include "Tiff2ioc.h"

// internal functions
void orderFlip( char *buffer, int n );


//------------------------------------------------------------------------------
//
// Main entry point.  Takes a toolbox page handle and a file path as input
//
//  Add a tiff image to an afp page using the toolbox
//  NOTE: assumes if this is not Windows, it's MVS & uses DD name TIFFDD
//
//------------------------------------------------------------------------------
//t AOCL_EXPORT_FUNCTION AFPInclTiff(TBHANDLE PageHandle, char* TiffName)
extern "OS"
{
int INCLTFF(TBHANDLE PageHandle, char* TiffName)   //@jls
{
  FILE *in, *out ;
  long int width, length, width4, byteWidth ;
  int line, nLines ;
  int rc;
  long i, j, n, offset, col, ctr ;

  TBHANDLE  ImgHandle ;

  uchar buff1024, *strip ;
  char doFlip = 0 ;
  uchar tagValue4 ;
  short nTags, tag, tagType, nToWrite ;
  int  tagCount, savedOffset, nWritten, bytesLeft, bytesWritten, planeLen ;
  int  *stripOffsets, *stripCounts, nStrips ;
  char *cPlane, *mPlane, *yPlane, *kPlane ;
  char masksݨ = { 0x80, 0x40, 0x20, 0x10, 0x08, 0x04, 0x02, 0x01 } ;
  char fnbuf100;

  #ifdef _Windows
  in = fopen( TiffName, "rb" ) ;
  #else
  char mvsf25 = "dd:TIFFDD(";
  strcat(mvsf,TiffName);
  strcat(mvsf,")");
  sprintf(fnbuf,"'%s'",TiffName);
  //fprintf(stderr,"tiff name is %s\n", fnbuf);
  in = fopen(mvsf,"rb");  // file not found??
  #endif
  if ( in == NULL ) {
     fprintf( stderr, "Input file not opened, errno %i.\n", errno );    ;
     perror("because");
     return errno;
     }

  /* set the flip */
  fread( &buff0, 8, 1, in ) ;
  if ( buff0 == 0x49 )
    doFlip = 1 ;

  // hack to get little endian windows to work
  #ifdef _Windows
  doFlip = 0;
  #endif


  /* get the IFD offset */
  if ( doFlip )
    orderFlip( (char *)&buff4, 4 ) ;
  memcpy( &offset, &buff4, 4 ) ;
  fseek( in, offset, SEEK_SET ) ;


  /* read the number of tags */
  fread( &nTags, 1, 2, in ) ;
  if ( doFlip )
    orderFlip( (char *)&nTags, 2 ) ;

  /* loop over the tags */
  for ( i = 0 ; i < nTags ; i++ )
    { /*3*/
      /* read the tag */

      fread( &tag, 2, 1, in ) ;
      if ( doFlip )
        orderFlip( (char *)&tag, 2 ) ;
      fread( &tagType, 2, 1, in ) ;
      if ( doFlip )
        orderFlip( (char *)&tagType, 2 ) ;
      fread( &tagCount, 4, 1, in ) ;
      if ( doFlip )
        orderFlip( (char *)&tagCount, 4 ) ;
      fread( &tagValue0, 4, 1, in ) ;

      /* process the tag if it's one of the ones we care about */

      switch ( tag ) { /*4*/
      case 256:  /* width */
         #ifdef _Windows
         orderFlip( (char *) &tagValue0, 2 ) ;
         #else
         if ( doFlip )
            orderFlip( (char *)&tagValue0, 2 ) ;      //@jls
         #endif
         width = ( tagValue0 << 8 )  tagValue1 ;
         width4 = 4 * width ;
         break ;
      case 257:  /* length */
       #ifdef _Windows
         orderFlip( (char *)&tagValue0, 2 ) ;   //@jls
         #else
         if ( doFlip )
            orderFlip( (char *)&tagValue0, 2 ) ;  //@jls
         #endif
         length = ( tagValue0 << 8 )  tagValue1 ;
         break ;
      case 273:  /* strip offsets */
         stripOffsets = (int *)malloc( tagCount * sizeof( int ) ) ;
         savedOffset = ftell( in ) ;
         if ( doFlip )
            orderFlip( (char *)&tagValue0, 4 ) ;  //@jls
         if ( tagCount > 1 )
            {
            memcpy( &offset, &tagValue0, 4 ) ;
            fseek( in, offset, SEEK_SET ) ;
            for ( n = 0 ; n < tagCount ; n++ )
               { /*5*/
               fread( &stripOffsetsn, 4, 1, in ) ;
               if ( doFlip )
                  orderFlip( (char *)&stripOffsetsn, 4 ) ;
               } /*5*/  /* end offset read loop */

            fseek( in, savedOffset, SEEK_SET ) ;
            }
         else
            memcpy( &stripOffsets0, &tagValue0, 4 ) ;

         break ;
      case 279:  /* strip byte counts */
         stripCounts = (int *)malloc( tagCount * sizeof( int ) ) ;
         nStrips = tagCount ;
         savedOffset = ftell( in ) ;
         if ( doFlip )
            orderFlip( (char *)&tagValue0, 4 ) ;
         if ( tagCount > 1 )
            {
            memcpy( &offset, &tagValue0, 4 ) ;
            fseek( in, offset, SEEK_SET ) ;
            for ( n = 0 ; n < tagCount ; n++ )
               { /*5*/
               fread( &stripCountsn, 4, 1, in ) ;
               if ( doFlip )
                  orderFlip( (char *)&stripCountsn, 4 ) ;
               } /*5*/  /* end offset read loop */
            fseek( in, savedOffset, SEEK_SET ) ;
            }
         else
            {
            memcpy( &stripCounts0, &tagValue0, 4 ) ;
            }
         break ;
      } /*4*/  /* end switch */

    } /*3*/ /* loop over tags */

  /* we should have all the data - width, length, offsets and counts. */
  /* Allocate the strip buffer */
  n = 0 ;
  for ( i = 0 ; i < nStrips ; i++ ) {
     if ( n < stripCountsi )
        n = stripCountsi ;
     }
  strip = (uchar *)malloc( n * sizeof( char ) ) ;

  /* prepare for output */
  rc = AFPBgnImage(PageHandle, "TIFF Image",3000,3000,width,length,
     IN_2_U1440(3),IN_2_U1440(1),
     0,0,POSITION_AND_TRIM_MOPT,
     DEG_0,&ImgHandle);

  /* loop through the strips */
  line = 0 ;
  for ( n = 0 ; n < nStrips ; n++ )
    {
      fseek( in, stripOffsetsn, SEEK_SET ) ;
      fread( strip, 1, stripCountsn, in ) ;
      ctr = stripCountsn ;
      rc = AFPImageData(PageHandle,ImgHandle,strip,ctr,
                        G4MMR,1,0);
    }        /* end loop through the strips */


  /* done */
  rc = AFPEndImage(PageHandle, &ImgHandle);
  fclose( in ) ;
  return 0;
}
}

//------------------------------------------------------------------------------
//------------------------------------------------------------------------------
//
//  Internal functions
//

//   Flip the byte order in the buffer (conversion between little and big
//   endians).

void orderFlip( char *buffer, int n )
{ /*1*/
  char w ;
  int  i, n2 ;
  n2 = (n-1)/2 ;
  for ( i = 0 ; i <= n2 ; i++ )
    { /*2*/
      w = bufferi ;
      bufferi = buffern-i-1 ;
      buffern-i-1 = w ;
    } /*2*/
} /*1*/

