       IDENTIFICATION DIVISION.
      ****************************************************************
      *   COBOL PROGRAM -- AFP TOOLBOX                               *
      *                                                              *
      * This program invokes the AFP Toolbox to produce a single     *
      * page of output, place a line of text and include an object   *
      * inline as part of the page. It also converts the object from *
      * TIFF to IOCA.                                                *
      *        >>>>>>>  IMPORTANT NOTICE   <<<<<<<<<<<
      *
      *   THIS PROGRAM IS NOT SUPPORTED IN ANY WAY BY IBM.  IT
      *   HAS NOT BEEN SUBJECTED TO ANY FORMAL IBM TESTING AND
      *   IS DISTRIBUTED ON AN "AS-IS" BASIS WITHOUT ANY
      *   WARRANTY EITHER EXPRESSED OR IMPLIED.  THE USE OF
      *   THIS CODE OR ANY INFORMATION OR TECHNIQUES IMPLICIT
      *   WITHIN IT IS THE SOLE RESPONSIBILITY OF THE CUSTOMER.
      *   SUCH USE DEPENDS UPON THE CUSTOMER'S ABILITY TO
      *   EVALUATE THE INFORMATION IN THE CONTEXT OF THEIR OWN
      *   PARTICULAR OPERATING ENVIRONMENT.  THIS CODE HAS
      *   OPERATED SUCCESSFULLY IN THE COMPUTING ENVIRONMENT AT
      *   THE BOULDER PROGRAMMING CENTER.  THERE IS NO
      *   GUARANTEE THAT IT WILL OPERATE CORRECTLY ELSEWHERE.
      *
      *
      ****************************************************************
       PROGRAM-ID. "TIFFTST".
       ENVIRONMENT DIVISION.

         CONFIGURATION SECTION.
          SOURCE-COMPUTER. IBM.
          OBJECT-COMPUTER. IBM.


      ****************************************************************
      *                                                              *
      *                    DATA DIVISION                             *
      *                                                              *
      ****************************************************************
       DATA DIVISION.

         WORKING-STORAGE SECTION.


          01  FONT-IDS.
               05  TIM10MED              PIC 9(4) BINARY VALUE 0.
          01  AFP-STRING-VARIABLES.
           03  AFP-STRING-1            PIC X(20)
               VALUE "TIFF image follows".
           03  INCTIFF                 PIC X(20)
               VALUE "INCLTFF".


           COPY ATXCBVAR.

      /---------------------------------------------------------------*
      ****************************************************************
      *                                                              *
      *   MAINLINE                                                   *
      *                                                              *
      *            Initialize the Toolbox                            *
      *            Begin the Document                                *
      *            Define font (TNR 10 pt)                           *
      *            Begin a page                                      *
      *            Set the font                                      *
      *            Write a string                                    *
      *            Include a TIFF object & convert to IOCA           *
      *            End the page                                      *
      *            End the Document                                  *
      *                                                              *
      ****************************************************************
       PROCEDURE DIVISION.


       MAINLINE.


           PERFORM SETUP-AFPTBOX.
             MOVE "Page 1" TO AFP-PAGE-NAME.
           PERFORM AFPBPAGE.


      *---------------------------------------------------------------*
      * Set new position over 1 inch and down 1 inch and              *
      *       write the text string.                                  *
      *---------------------------------------------------------------*
             MOVE 1440 TO AFP-X-COORDINATE.
             MOVE ABSOLUTE-POS TO AFP-X-REF-COORD-SYS.
             MOVE 1440 TO AFP-Y-COORDINATE.
             MOVE ABSOLUTE-POS TO AFP-Y-REF-COORD-SYS.
           PERFORM AFPSPOS.

      *---------------------------------------------------------------*
      * Set the font for the string of text                           *
      *---------------------------------------------------------------*
             MOVE TIM10MED TO AFP-FONT-ID.
           PERFORM AFPSFONT.

      *---------------------------------------------------------------*
      * Write the string left-aligned at the current position         *
      *---------------------------------------------------------------*
             MOVE AFP-STRING-1 TO AFP-CHARACTER-STRING.
             MOVE 18 TO AFP-STRING-LENGTH.
             MOVE LEFT-ALIGN TO AFP-ALIGNMENT-OPTION.
             MOVE TRU TO AFP-POSITION-OPTION.
           PERFORM AFPWRITE.

      *---------------------------------------------------------------*
      * Move down a line                                              *
      *---------------------------------------------------------------*
           PERFORM AFPNLINE.

      *---------------------------------------------------------------*
      * Include a TIFF image                                          *
      *---------------------------------------------------------------*
             MOVE "TESTSIG" TO AFP-OBJECT-NAME.
             CALL "TRIM" USING AFP-OBJECT-NAME,
                           BY CONTENT LENGTH OF AFP-OBJECT-NAME,
                           BY REFERENCE AFP-NAME-STRING,
                           AFP-NAME-LENGTH.
               ADD 1 TO AFP-NAME-LENGTH
               MOVE LOW-VALUES TO AFP-OBJECT-NAME(AFP-NAME-LENGTH:1)
           CALL  "INCLTFF"
                     USING
                     BY VALUE
                        AFP-PAGE-HANDLE
                     BY CONTENT
                        AFP-OBJECT-NAME.

      *---------------------------------------------------------------*
      * End the page and document & terminate the toolbox.            *
      *---------------------------------------------------------------*
           PERFORM AFPEPAGE.
           PERFORM END-PROCESSING.
           STOP RUN.

      /---------------------------------------------------------------*
      *---------------------------------------------------------------*
      *                                                               *
      *    SETUP-AFPTBOX.                                             *
      *        Initialize the session.                                *
      *        Begin a document.                                      *
      *        Define the fonts.                                      *
      *                                                               *
      *---------------------------------------------------------------*


       SETUP-AFPTBOX.
      *---------------------------------------------------------------*
      *                                                               *
      *    Define the 10 point Times New Roman Font                   *
      *                                                               *
      *---------------------------------------------------------------*
               MOVE "T1V10500" TO AFP-CODE-PAGE.
               MOVE "TIMES NEW ROMAN LATIN1" TO AFP-DESCRIPTIVE-NAME.
               MOVE 100 TO AFP-POINT-SIZE.
               MOVE MEDIUM TO AFP-WEIGHT.
               MOVE NORML TO AFP-FONT-WIDTH.
               MOVE ROMAN TO AFP-STYLE.
           PERFORM AFPDFNTAT.
               MOVE AFP-FONT-ID TO TIM10MED.
           PERFORM AFPINIT.

      *---------------------------------------------------------------*
      *                                                               *
      *    Begin the document and specify the output file.            *
      *    NOTE: MYOUTPUT is assumed to be the DD name for output.    *
      *                                                               *
      *---------------------------------------------------------------*
               MOVE "SAMPLE PAGE WITH OVERLAY" TO AFP-DOC-NAME.
               MOVE "MVS COBOL Program" TO AFP-DOC-COMMENT.
               MOVE FILED TO AFP-OUTPUT-TYPE.
               MOVE "FILEOUT"
                       TO AFP-OUTPUT-FILENAME.
           PERFORM AFPBDOC.


      /---------------------------------------------------------------*
      *---------------------------------------------------------------*
      *                                                               *
      *    TERMINATE THE AFPAPI AND THE PROGRAM                      *
      *                                                               *
      *---------------------------------------------------------------*

       END-PROCESSING.
           PERFORM AFPEDOC.
           PERFORM AFPEND.

           COPY ATXCBPRF.
           COPY ATXTRIM.
           COPY ATXSTRL.

       END PROGRAM "TIFFTST".
